@@ -7,7 +7,7 @@ function( rates,
         ygrid = grid,
      col.grid = gray( 0.9 ),
         c.lim = NULL,
-         ylim = range( rates, na.rm=TRUE ),
+         ylim = range( rates[rates>0], na.rm=TRUE ),
            at = NULL,
        labels = paste( at ),
         c.lab = names( dimnames( rates ) )[2],
